﻿

using BPA.KitChen.GroupMealOrder.Application.BaseDto;
using BPA.KitChen.GroupMealOrder.Application.Service.AExternalPlatform.Service.WeighOrder.Serviec;
using BPA.KitChen.GroupMealOrder.Application.Service.WeighOrder.Dtos;
using BPA.KitChen.GroupMealOrder.Application.Service.WeighOrder.Service;
using BPA.KitChen.GroupMealOrder.Core;
using Furion.DynamicApiController;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;

namespace BPA.KitChen.GroupMealOrder.Application.Service.AExternalPlatform.Service.WeighOrder
{

    [ApiDescriptionSettings("开放平台", Tag = "称重订单"), AllowAnonymous]
    public class WeighOrderServices: IDynamicApiController
    {
        private readonly IWeighOrderService _weighOrderService;
        public WeighOrderServices(IWeighOrderService weighOrderService)
        {
            _weighOrderService = weighOrderService;
        }

        /// <summary>
        /// 创建订单
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        [HttpPost("/api/ExternalPlatform/WeighOrder/CreateWeighOrder")]
        public async Task<WeighOrderDto> CreateWeighOrder(WeighOrderCreteDto inputDto)
        {
            return await _weighOrderService.CreateWeighOrder(inputDto);
        }

        /// <summary>
        /// 添加订单商品
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        [HttpPost("/api/ExternalPlatform/WeighOrder/AddWeighOrderGoods")]
        public async Task<bool> AddWeighOrderGoods(AddWeighOrderGoodsDto inputDto)
        {
            return await _weighOrderService.AddWeighOrderGoods(inputDto.Data);
        }

        /// <summary>
        /// 添加订单餐盘
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        [HttpPost( "/api/ExternalPlatform/WeighOrder/AddWeighOrderDiningPlate")]
        public async Task<bool> AddWeighOrderDiningPlate(AddWeighOrderDiningPlateDto inputDto)
        {
            return await _weighOrderService.AddWeighOrderDiningPlate(inputDto.Data);
        }

    

        /// <summary>
        /// 查询称重订单信息 按订单号
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        [HttpPost("/api/ExternalPlatform/WeighOrder/GetWeighOrderByOrderId")]
        public async Task<WeighOrderDto> GetWeighOrderByOrderId(GetWeighOrderByOrderIdInputDto inputDto)
        {
            return await _weighOrderService.GetWeighOrderByOrderId(inputDto);
        }

        /// <summary>
        /// 查询称重订单信息 按芯片码
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        [HttpPost("/api/ExternalPlatform/WeighOrder/GetWeighOrderByChipCode")]
        public async Task<WeighOrderDto> GetWeighOrderByChipCode(GetWeighOrderByChipCodeInputDto inputDto)
        {
            return await _weighOrderService.GetWeighOrderByChipCode(inputDto);
        }


        /// <summary>
        /// 修改订单状态
        /// </summary>
        /// <returns></returns>
        [HttpPost( "/api/ExternalPlatform/WeighOrder/UpdateWeighOrderStates")]
        public async Task<bool> UpdateWeighOrderStates(WeighOrderUpdateDto inputDto)
        {

            return await _weighOrderService.UpdateWeighOrderStates(inputDto);
        }

        /// <summary>
        /// 更具openid获取称重订单
        /// </summary>
        /// <returns></returns>
        [HttpPost("/api/ExternalPlatform/WeighOrder/GetWeighOrderPageByOpenId")]
        public async Task<PageUtil> GetWeighOrderPageByOpenId(GetWeighOrderPageByOpenIdInputDto inputDto)
        {
            return await _weighOrderService.GetWeighOrderPageByOpenId(inputDto);
        }

        /// <summary>
        /// 更具openid获取称重订单
        /// </summary>
        /// <returns></returns>
        [HttpPost("/api/ExternalPlatform/WeighOrder/GetWeighOrderByOpenId")]
        public async Task<WeighOrderDto> GetWeighOrderByOpenId(GetWeighOrderByOpenIdInputDto inputDto)
        {
            return await _weighOrderService.GetWeighOrderByOpenId(inputDto);
        }
    }
}
