﻿
using BPA.KitChen.GroupMealOrder.Core.Enum;
using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BPA.KitChen.GroupMealOrder.Application.Service.Order.Dtos
{
    public class NormalNewOrderDto: NewOrderBasicDto
    {
        /// <summary>
        /// 实际金额
        /// </summary>
        public decimal RealMoney { get; set; } = 0;
        /// <summary>
        /// 优惠券金额
        /// </summary>
        public decimal CouponPrice { get; set; } = 0;
        /// <summary>
        /// 用户领取优惠券Id
        /// </summary>
        public string CouponCustomerId { get; set; } = string.Empty;
        /// <summary>
        /// 活动折扣金额
        /// </summary>
        public decimal DisCountPrice { get; set; } = 0;
        /// <summary>
        /// 会员优惠金额
        /// </summary>
        public decimal VipCountPrice { get; set; } = 0;
        /// <summary>
        /// 支付渠道<see cref="PayModelEnum"/>
        /// </summary>
        public PayModelEnum PayMode { get; set; } = PayModelEnum.WeiXin;
        /// <summary>
        /// 订单类型 <see cref="OrderTypeEnum"/>
        /// </summary>
        public OrderTypeEnum SubOrderType { get; set; } = OrderTypeEnum.Normal;
        /// <summary>
        /// 通知地址
        /// </summary>
        public string NotifyUrl { get; set; }
        /// <summary>
        /// 桌号
        /// </summary>
        public int DeskCode { get; set; }
        /// <summary>
        /// 就餐方式
        /// <see cref="EatTypeEnum"/>
        /// </summary>
        public EatTypeEnum EatType { get; set; }
        /// <summary>
        /// 小票备注
        /// </summary>
        public string PrintRemark { get; set; }
        /// <summary>
        /// 店铺Id
        /// </summary>
        public string StoreId { get; set; }
        /// <summary>
        /// 冒菜用户选购信息
        /// </summary>
        public List<NewOrderMCDto> MCInfo { get; set; }
    }

    public class NewOrderBasicDto
    {
        /// <summary>
        /// 订单号
        /// </summary>
        public string OrderNumber { get; set; }
        /// <summary>
        /// 客户Id
        /// </summary>
        public string UserId { get; set; }
        /// <summary>
        /// 子订单信息
        /// </summary>
        public List<NewOrderSubOrderInfoDto> SubOrderInfo { get; set; }
        /// <summary>
        /// 加购商品信息
        /// </summary>
        public List<NewOrderSubOrderInfoDto> AddFoodInfo { get; set; }
        /// <summary>
        /// 特价子商品
        /// </summary>
        public List<NewOrderBasicPriceDto> DisCountSubOrder { get; set; }
    }
    public class NewOrderBasicPriceDto
    {
        /// <summary>
        /// 价格
        /// </summary>
        public decimal Price { get; set; }
        /// <summary>
        /// 商品Id
        /// </summary>
        public string GoodId { get; set; }
    }

    public class NewOrderSubOrderInfoDto
    {
        /// <summary>
        /// 商品Id
        /// </summary>
        public string FoodMenuId { get; set; }
        /// <summary>
        /// 做法名称
        /// </summary>
        public string MakeName { get; set; }
        /// <summary>
        /// 做法ID
        /// </summary>
        public string MakeId { get; set; }
        /// <summary>
        /// 是否设备
        /// </summary>
        public int IsDevice { get; set; }
        /// <summary>
        /// 是否赠送
        /// </summary>
        public bool IsGift { get; set; } = false;
    }

    public class NewOrderMCDto
    {
        /// <summary>
        /// 子订单菜品Id
        /// </summary>
        public string SubGoodId { get; set; }
        /// <summary>
        /// 冒菜配料Id
        /// </summary>
        public string McId { get; set; }
        /// <summary>
        /// 数量
        /// </summary>
        public int Count { get; set; }
    }
}
