﻿using BPA.KitChen.GroupMealOrder.Application.BaseDto;
using BPA.KitChen.GroupMealOrder.Application.Service.AExternalPlatform.BaseDto;
using BPA.KitChen.GroupMealOrder.Application.Service.AExternalPlatform.Enum;
using BPA.KitChen.GroupMealOrder.Application.Service.AExternalPlatform.Service.CheckService.Services.Dtos;
using BPA.KitChen.GroupMealOrder.Application.Service.ThirdAuthorize;
using BPA.KitChen.GroupMealOrder.Application.Service.WeighOrder.Dtos;
using BPA.KitChen.GroupMealOrder.Core;
using BPA.KitChen.GroupMealOrder.Core.Common;
using BPA.KitChen.GroupMealOrder.Core.Entity;
using BPA.KitChen.GroupMealOrder.SqlSugar;
using Furion.DatabaseAccessor;
using Furion;
using Furion.DependencyInjection;
using Furion.DynamicApiController;
using Furion.FriendlyException;
using Microsoft.AspNetCore.Components.Forms;
using Microsoft.AspNetCore.Hosting;
using Newtonsoft.Json;
using NPOI.SS.Formula.Functions;
using SqlSugar;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace BPA.KitChen.GroupMealOrder.Application.Service.WeighOrder.Service
{
    public class WeighOrderService : ITransient, IWeighOrderService
    {
        private readonly SqlSugarScope db;

        public WeighOrderService()
        {
            db = SqlSugarDb.Db;
        }

        /// <summary>
        /// 创建订单
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        public async Task<WeighOrderDto> CreateWeighOrder(WeighOrderCreteDto inputDto)
        {
            var diningPlateInfo =await GetDiningPlateInfoByQRCode(inputDto.QRCode);
            if (diningPlateInfo==null|| diningPlateInfo.Status!=0)
            {
                throw Oops.Oh("餐盘不存在或者被停用");
            }
            var result = new WeighOrderDto();

            var diningPlateOccupyl = await GetDiningPlateOccupyInfo(new List<string>() { inputDto.QRCode});

            var thisDiningPlate = diningPlateOccupyl.FirstOrDefault(x => x.DiningPlateId == diningPlateInfo.Id);
            if (thisDiningPlate != null && thisDiningPlate.IsOccupy)
            {
                throw Oops.Oh("餐盘被占用");
            }


            var order = new BPA_WeighOrder()
            {
                CreateAt = DateTime.Now,
                GroupId = CurrentUser.TenantId,
                CreateId = inputDto.CreateId,
                OrderNumber = Guid.NewGuid().ToString(),
                Id = Guid.NewGuid().ToString(),
                PayStates = 0,
                SceneId = CurrentUser.StoreId,
                States = 0,
                TotalAmount =0,
                Subject ="",
            };
            //添加订单
            var res = await db.Insertable(order).ExecuteCommandAsync();


            var diningPlate = new List<BPA_WeighOrderDiningPlate>();
            diningPlate.Add(new BPA_WeighOrderDiningPlate()
            {
                DiningPlateId = diningPlateInfo.Id,
                GroupId = CurrentUser.TenantId,
                WeighOrderId = order.Id,
                ChipCode = diningPlateInfo.ChipCode,
                QRCode = diningPlateInfo.QRCode,
                Id = Guid.NewGuid().ToString(),
            });

            //添加子订单
            if (res > 0)
            {
                result = new WeighOrderDto()
                {
                    CreateAt = order.CreateAt,
                    CreateId = order.CreateId,
                    GroupId = order.GroupId,
                    Id = order.Id,
                    OrderNumber = order.OrderNumber,
                    PayStates = order.PayStates,
                    SceneId = order.SceneId,
                    States = order.States,
                    Subject ="",
                    TotalAmount = order.TotalAmount,
                };
                await db.Insertable(diningPlate).ExecuteCommandAsync();
            }

            result = await GetWeighOrderByOrderId(new GetWeighOrderByOrderIdInputDto()
            {
                OrderId = order.Id,
            });

            return result;
        }



        /// <summary>
        /// 添加订单商品
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        public async Task<bool> AddWeighOrderGoods(List<WeighOrderGoodsCreateDto> inputDto)
        {
            var ids = inputDto.Select(x => x.OrderId).FirstOrDefault();
            var weighOrder = await db.Queryable<BPA_WeighOrder>().FirstAsync(x => x.Id == ids);
            if (weighOrder == null || weighOrder.States == 1)
            {
                throw Oops.Oh("订单不存在或者已完成");
            }

            var goodsList = await GetGoodsList(inputDto.Select(x => x.GoodsId).ToList());
            if (goodsList == null)
            {
                throw Oops.Oh("商品不存在");
            }

            var orderGoods = new List<BPA_WeighOrderGoods>();
            foreach (var item in inputDto)
            {
                var thisGoods = goodsList.FirstOrDefault(x => x.Id == item.GoodsId);
                if (thisGoods == null)
                {
                    throw Oops.Oh("商品不存在");
                }

                orderGoods.Add(new BPA_WeighOrderGoods()
                {
                    GoodsAttribute = "",
                    GoodsId = item.GoodsId,
                    GoodsName = item.GoodsName,
                    GoodsWeight = item.GoodsWeight,
                    GroupId = CurrentUser.TenantId,
                    OrderId = item.OrderId,
                    TotalAmount = thisGoods.Price * item.GoodsWeight,
                    Id = Guid.NewGuid().ToString(),

                });
            }

            var res = await db.Insertable(orderGoods).ExecuteCommandAsync();

            return res > 0;
        }

        /// <summary>
        /// 添加订单餐盘
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        public async Task<bool> AddWeighOrderDiningPlate(List<WeighOrderDiningPlateCreateDto> inputDto)
        {
            var ids = inputDto.Select(x => x.OrderId).FirstOrDefault();
            var weighOrder = await db.Queryable<BPA_WeighOrder>().FirstAsync(x => x.Id == ids);
            if (weighOrder == null || weighOrder.States == 1)
            {
                throw Oops.Oh("订单不存在或者已完成");
            }

            var diningPlateOccupyl = await GetDiningPlateOccupyInfo(inputDto.Select(x => x.DiningPlateId).ToList());

            var diningPlate = new List<BPA_WeighOrderDiningPlate>();
            foreach (var item in inputDto)
            {
                var thisDiningPlate = diningPlateOccupyl.FirstOrDefault(x => x.DiningPlateId == item.DiningPlateId);
                if (thisDiningPlate == null || thisDiningPlate.IsOccupy)
                {
                    throw Oops.Oh("餐盘被占用");
                }
                diningPlate.Add(new BPA_WeighOrderDiningPlate()
                {
                    DiningPlateId = item.DiningPlateId,
                    GroupId = CurrentUser.TenantId,
                    WeighOrderId = item.OrderId,
                    QRCode = item.QRCode,
                    ChipCode = item.ChipCode,
                    Id = Guid.NewGuid().ToString(),
                });
            }

            var res = await db.Insertable(diningPlate).ExecuteCommandAsync();
            return res > 0;
        }

        /// <summary>
        /// 查询称重订单信息 按订单号
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        public async Task<WeighOrderDto> GetWeighOrderByOrderId(GetWeighOrderByOrderIdInputDto inputDto)
        {
            var result = new WeighOrderDto();

            //查询订单
            result = await db.Queryable<BPA_WeighOrderDiningPlate, BPA_WeighOrder, BPA_WeighOrderDiningPlateUnbindRecord>((a, b, c) => new JoinQueryInfos(
                    JoinType.Left, a.WeighOrderId == b.Id,
                    JoinType.Left, a.DiningPlateId == c.DiningPlateId && a.WeighOrderId == c.WeighOrderId))
                .WhereIF(!string.IsNullOrEmpty(inputDto.OrderId), (a, b, c) => b.Id == inputDto.OrderId)
                .Select((a, b, c) => new WeighOrderDto
                {
                    CreateAt = b.CreateAt,
                    CreateId = b.CreateId,
                    GroupId = b.GroupId,
                    Id = b.Id,
                    OrderNumber = b.OrderNumber,
                    PayStates = b.States,
                    SceneId = b.SceneId,
                    States = b.States,
                    Subject = b.Subject,
                    TotalAmount = b.TotalAmount,
                })
                .FirstAsync();
            if (result == null)
            {
                throw Oops.Oh("订单不存在或者已完成");
            }

            //查询订单商品
            var orderGoods = await db.Queryable<BPA_WeighOrderGoods>()
                .Where(x => x.OrderId == inputDto.OrderId)
                .ToListAsync();

            if (orderGoods.Count > 0)
            {
                result.GoodsInfo = orderGoods.Select(x => new WeighOrderGoodsDto()
                {
                    GoodsId = x.GoodsId,
                    GoodsAttribute = null, //string.IsNullOrEmpty(x.GoodsAttribute) ? null : JsonConvert.DeserializeObject<List<GoogsAttribute>>(x.GoodsAttribute),
                    GoodsName = x.GoodsName,
                    GoodsWeight = x.GoodsWeight,
                    GroupId = x.GroupId,
                    Id = x.Id,
                    OrderId = x.OrderId,
                }).ToList();


                result.GoodsInfo = result.GoodsInfo.GroupBy(x => new { x.GroupId, x.GoodsAttribute, x.GoodsName, x.OrderId })
                    .Select(x => new WeighOrderGoodsDto()
                    {
                        GoodsAttribute = x.FirstOrDefault()?.GoodsAttribute,
                        GoodsId = x.FirstOrDefault()?.GoodsId,
                        GoodsName = x.FirstOrDefault()?.GoodsName,
                        GoodsWeight = x.Sum(p=>p.GoodsWeight),
                        GroupId = x.FirstOrDefault()?.GroupId,
                        OrderId = x.FirstOrDefault()?.OrderId,
                        TotalAmount=x.Sum(p=>p.TotalAmount)
                    })
                    .ToList();
                result.TotalAmount = result.GoodsInfo.Sum(x => x.TotalAmount);
            }


            //查询订单餐盘
            var diningPlate = await db.Queryable<BPA_WeighOrderDiningPlate>()
                 .Where(x => x.WeighOrderId == inputDto.OrderId)
                 .Select(x => new WeighOrderDiningPlateDto()
                 {
                     DiningPlateId = x.DiningPlateId,
                     OrderId = inputDto.OrderId,
                     ChipCode = x.ChipCode,
                     QRCode = x.QRCode,
                 }).ToListAsync();
            result.DiningPlateInfo = diningPlate;



            return result;
        }

        /// <summary>
        /// 查询称重订单信息 按芯片码
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        public async Task<WeighOrderDto> GetWeighOrderByChipCode(GetWeighOrderByChipCodeInputDto inputDto)
        {
            var result = new WeighOrderDto();

            //查询订单
            result = await db.Queryable<BPA_WeighOrderDiningPlate, BPA_WeighOrder, BPA_WeighOrderDiningPlateUnbindRecord>((a, b, c) => new JoinQueryInfos(
                    JoinType.Left, a.WeighOrderId == b.Id,
                    JoinType.Left, a.DiningPlateId == c.DiningPlateId && a.WeighOrderId == c.WeighOrderId))
                .Where((a, b, c) => a.ChipCode == inputDto.ChipCode && b.States == 0)
                .Select((a, b, c) => new WeighOrderDto
                {
                    CreateAt = b.CreateAt,
                    CreateId = b.CreateId,
                    GroupId = b.GroupId,
                    Id = b.Id,
                    OrderNumber = b.OrderNumber,
                    PayStates = b.States,
                    SceneId = b.SceneId,
                    States = b.States,
                    Subject = b.Subject,
                    TotalAmount = b.TotalAmount,
                }).FirstAsync();

            if (result == null)
            {
                throw Oops.Oh("订单不存在或者已完成");
            }

            //查询订单商品
            var orderGoods = await db.Queryable<BPA_WeighOrderGoods>()
                .Where(x => x.OrderId == result.Id)
                .ToListAsync();

            result.GoodsInfo = orderGoods.Select(x => new WeighOrderGoodsDto()
            {
                GoodsId = x.GoodsId,
                GoodsAttribute = string.IsNullOrEmpty(x.GoodsAttribute) ? null : JsonConvert.DeserializeObject<List<GoogsAttribute>>(x.GoodsAttribute),
                GoodsName = x.GoodsName,
                GoodsWeight = x.GoodsWeight,
                GroupId = x.GroupId,
                Id = x.Id,
                OrderId = x.OrderId,
                TotalAmount = x.TotalAmount,
            }).ToList();


            result.GoodsInfo = result.GoodsInfo.GroupBy(x => new { x.GroupId, x.GoodsAttribute, x.GoodsName, x.OrderId })
                .Select(x => new WeighOrderGoodsDto()
                {
                    GoodsAttribute = x.FirstOrDefault()?.GoodsAttribute,
                    GoodsId = x.FirstOrDefault()?.GoodsId,
                    GoodsName = x.FirstOrDefault()?.GoodsName,
                    GoodsWeight = x.Sum(p => p.GoodsWeight),
                    GroupId = x.FirstOrDefault()?.GroupId,
                    OrderId = x.FirstOrDefault()?.OrderId,
                    TotalAmount = x.Sum(p => p.TotalAmount),
                })
                .ToList();

            //查询订单餐盘
            var diningPlate = await db.Queryable<BPA_WeighOrderDiningPlate>()
                 .Where(x => x.WeighOrderId == result.Id)
                 .Select(x => new WeighOrderDiningPlateDto()
                 {
                     DiningPlateId = x.DiningPlateId,
                     OrderId = result.Id,
                     ChipCode = x.ChipCode,
                     QRCode = x.QRCode
                 }).ToListAsync();
            result.DiningPlateInfo = diningPlate;

            result.TotalAmount = result.GoodsInfo.Sum(x => x.TotalAmount);

            return result;
        }


        /// <summary>
        /// 修改订单状态
        /// </summary>
        /// <returns></returns>
        public async Task<bool> UpdateWeighOrderStates(WeighOrderUpdateDto inputDto)
        {
            //查询订单
            var result = await db.Queryable<BPA_WeighOrder>()
                 .FirstAsync(x => x.Id == inputDto.OrderId);

            result.PayStates = inputDto.PayStates;
            result.States = inputDto.States;
            await db.Insertable(new BPA_WeighOrderStatesRecord()
            {
                BeforeTheChange = result.States,
                AfterTheChange = inputDto.States,
                CreateAt = DateTime.Now,
                OrderId = inputDto.OrderId,
                Id = Guid.NewGuid().ToString(),
                GroupId = CurrentUser.TenantId

            }).ExecuteCommandAsync();
            var res = await db.Updateable(result).ExecuteCommandAsync();

            return res > 0;
        }

        /// <summary>
        /// 添加 餐盘解绑记录
        /// </summary>
        /// <param name="inputDto">餐盘ID</param>
        /// <returns></returns>
        public async Task<bool> AddWeighOrderDiningPlateUnbindRecord(List<DiningPlateDto> inputDto)
        {
            var list = new List<BPA_WeighOrderDiningPlateUnbindRecord>();

            foreach (var item in inputDto)
            {
                list.Add(new BPA_WeighOrderDiningPlateUnbindRecord()
                {
                    CreateAt = DateTime.Now,
                    DiningPlateId = item.DiningPlateId,
                    WeighOrderId = item.WeighOrderId,
                });
            }

            if (list.Count > 0)
            {
                var res = await db.Insertable(list).ExecuteCommandAsync();
                return res > 0;
            }

            return false;
        }

        /// <summary>
        /// 获取餐盘绑定信息
        /// </summary>
        /// <param name="inputDto">餐盘ID</param>
        /// <returns></returns>
        public async Task<List<DiningPlateDto>> GetDiningPlateOccupyInfo(List<string> inputDto)
        {
            var data = await db.Queryable<BPA_WeighOrderDiningPlate, BPA_WeighOrderDiningPlateUnbindRecord, BPA_WeighOrder>
                    ((a, b, c) => new JoinQueryInfos(
                        JoinType.Left, a.WeighOrderId == b.WeighOrderId && a.DiningPlateId == b.DiningPlateId,
                        JoinType.Left, a.WeighOrderId == c.Id))
                .WhereIF(inputDto.Count > 0, (a, b, c) => inputDto.Contains(a.DiningPlateId))
                .Select((a, b, c) => new DiningPlateDto()
                {
                    DiningPlateId = a.DiningPlateId,
                    IsOccupy = c.States == 1 ? false : (b == null || b.Id == null) ? true : false,
                    WeighOrderId = c.Id
                }).ToListAsync();


            data = data.Where(x => x.IsOccupy == true).ToList();

            return data;

        }


        /// <summary>
        /// 更具openid获取称重订单 分页
        /// </summary>
        /// <returns></returns>
        public async Task<PageUtil> GetWeighOrderPageByOpenId(GetWeighOrderPageByOpenIdInputDto inputDto)
        {
            int total = 0;
            var res = db.Queryable<BPA_WeighOrder>()
                .Where(x => x.CreateId == inputDto.OpenId)
                .OrderBy(x => x.CreateAt, OrderByType.Desc)
                .Select(t => new WeighOrderDto
                {
                    Id = t.Id.SelectAll(),
                }).ToPageList(inputDto.Current, inputDto.PageSize, ref total);

            foreach (var item in res)
            {
                //查询订单商品
                var orderGoods = await db.Queryable<BPA_WeighOrderGoods>()
                    .Where(x => x.OrderId == item.Id)
                    .ToListAsync();

                item.GoodsInfo = orderGoods.Select(x => new WeighOrderGoodsDto()
                {
                    GoodsId = x.GoodsId,
                    GoodsAttribute = string.IsNullOrEmpty(x.GoodsAttribute) ? null : JsonConvert.DeserializeObject<List<GoogsAttribute>>(x.GoodsAttribute),
                    GoodsName = x.GoodsName,
                    GoodsWeight = x.GoodsWeight,
                    GroupId = x.GroupId,
                    Id = x.Id,
                    OrderId = x.OrderId,
                }).ToList();


                item.GoodsInfo = item.GoodsInfo
                    .GroupBy(x => x.GroupId)
                    .Select(x => new WeighOrderGoodsDto()
                    {
                        GoodsAttribute = x.FirstOrDefault()?.GoodsAttribute,
                        GoodsId = x.FirstOrDefault()?.GoodsId,
                        GoodsName = x.FirstOrDefault()?.GoodsName,
                        GoodsWeight = x.Sum(p => p.GoodsWeight),
                        GroupId = x.FirstOrDefault()?.GroupId,
                        OrderId = x.FirstOrDefault()?.OrderId,
                    })
                    .ToList();

                //查询订单餐盘
                var diningPlate = await db.Queryable<BPA_WeighOrderDiningPlate>()
                    .Where(x => x.WeighOrderId == item.Id)
                    .Select(x => new WeighOrderDiningPlateDto()
                    {
                        DiningPlateId = x.DiningPlateId,
                        OrderId = x.WeighOrderId,
                        ChipCode = x.ChipCode,
                        QRCode = x.QRCode,
                    }).ToListAsync();
                item.DiningPlateInfo = diningPlate;

                item.TotalAmount = item.GoodsInfo.Sum(x => x.TotalAmount);
            }


            return new PageUtil()
            {
                Total = total,
                Data = res

            };
        }

        /// <summary>
        /// 更具openid获取称重订单
        /// </summary>
        /// <returns></returns>
        public async Task<WeighOrderDto> GetWeighOrderByOpenId(GetWeighOrderByOpenIdInputDto inputDto)
        {
            var res = await db.Queryable<BPA_WeighOrder>()
                .Where(x => x.CreateId == inputDto.OpenId)
                .OrderBy(x => x.CreateAt, OrderByType.Desc)
                .Select(t => new WeighOrderDto
                {
                    Id = t.Id.SelectAll(),
                }).FirstAsync();

            if (res==null&&res.States==1)
            {
                throw Oops.Oh("无数据");
            }

            //查询订单商品
            var orderGoods = await db.Queryable<BPA_WeighOrderGoods>()
                .Where(x => x.OrderId == res.Id)
                .ToListAsync();

            res.GoodsInfo = orderGoods.Select(x => new WeighOrderGoodsDto()
            {
                GoodsId = x.GoodsId,
                GoodsAttribute = string.IsNullOrEmpty(x.GoodsAttribute) ? null : JsonConvert.DeserializeObject<List<GoogsAttribute>>(x.GoodsAttribute),
                GoodsName = x.GoodsName,
                GoodsWeight = x.GoodsWeight,
                GroupId = x.GroupId,
                Id = x.Id,
                OrderId = x.OrderId,
            }).ToList();


            res.GoodsInfo = res.GoodsInfo
                .GroupBy(x => x.GroupId)
                .Select(x => new WeighOrderGoodsDto()
                {
                    GoodsAttribute = x.FirstOrDefault()?.GoodsAttribute,
                    GoodsId = x.FirstOrDefault()?.GoodsId,
                    GoodsName = x.FirstOrDefault()?.GoodsName,
                    GoodsWeight = x.Sum(p => p.GoodsWeight),
                    GroupId = x.FirstOrDefault()?.GroupId,
                    OrderId = x.FirstOrDefault()?.OrderId,
                })
                .ToList();

            //查询订单餐盘
            var diningPlate = await db.Queryable<BPA_WeighOrderDiningPlate>()
                .Where(x => x.WeighOrderId == res.Id)
                .Select(x => new WeighOrderDiningPlateDto()
                {
                    DiningPlateId = x.DiningPlateId,
                    OrderId = x.WeighOrderId,
                    ChipCode = x.ChipCode,
                    QRCode = x.QRCode,
                }).ToListAsync();
            res.DiningPlateInfo = diningPlate;

            res.TotalAmount = res.GoodsInfo.Sum(x => x.TotalAmount);

            return res;
        }


        /// <summary>
        /// 称重订单分页
        /// </summary>
        /// <param name="inputDto"></param>
        /// <returns></returns>
        public async Task<PageUtil> GetWeighOrderPage(GetGoodsListInputDto inputDto)
        {
            int total = 0;
            var res = db.Queryable<BPA_WeighOrder>()
                .OrderBy(x => x.CreateAt, OrderByType.Desc)
                .WhereIF(inputDto.states.HasValue,x=>x.States==inputDto.states)
                .WhereIF(inputDto.payStates.HasValue, x => x.PayStates == inputDto.payStates)
                .Select(t => new WeighOrderDto
                {
                    Id = t.Id.SelectAll(),
                }).ToPageList(inputDto.Current, inputDto.PageSize, ref total);

            foreach (var item in res)
            {
                //查询订单商品
                var orderGoods = await db.Queryable<BPA_WeighOrderGoods>()
                    .Where(x => x.OrderId == item.Id)
                    .ToListAsync();

                item.GoodsInfo = orderGoods.Select(x => new WeighOrderGoodsDto()
                {
                    GoodsId = x.GoodsId,
                    GoodsAttribute = string.IsNullOrEmpty(x.GoodsAttribute) ? null : JsonConvert.DeserializeObject<List<GoogsAttribute>>(x.GoodsAttribute),
                    GoodsName = x.GoodsName,
                    GoodsWeight = x.GoodsWeight,
                    GroupId = x.GroupId,
                    Id = x.Id,
                    OrderId = x.OrderId,
                }).ToList();


                item.GoodsInfo = item.GoodsInfo
                    .GroupBy(x => x.GroupId)
                    .Select(x => new WeighOrderGoodsDto()
                    {
                        GoodsAttribute = x.FirstOrDefault()?.GoodsAttribute,
                        GoodsId = x.FirstOrDefault()?.GoodsId,
                        GoodsName = x.FirstOrDefault()?.GoodsName,
                        GoodsWeight = x.Sum(p => p.GoodsWeight),
                        GroupId = x.FirstOrDefault()?.GroupId,
                        OrderId = x.FirstOrDefault()?.OrderId,
                    })
                    .ToList();

                //查询订单餐盘
                var diningPlate = await db.Queryable<BPA_WeighOrderDiningPlate>()
                    .Where(x => x.WeighOrderId == item.Id)
                    .Select(x => new WeighOrderDiningPlateDto()
                    {
                        DiningPlateId = x.DiningPlateId,
                        OrderId = x.WeighOrderId,
                        ChipCode = x.ChipCode,
                        QRCode = x.QRCode,
                    }).ToListAsync();
                item.DiningPlateInfo = diningPlate;

                item.TotalAmount = item.GoodsInfo.Sum(x => x.TotalAmount);
            }


            return new PageUtil()
            {
                Total = total,
                Data = res

            };
        }


        /// <summary>
        /// 获取商品信息
        /// </summary>
        /// <param name="ids"></param>
        /// <returns></returns>
        private async Task<List<GoodsInfoBaseView>> GetGoodsList(List<string> ids)
        {
            var res = new List<GoodsInfoBaseView>();

            try
            {
                Dictionary<string, string> dic = new Dictionary<string, string>();
                dic.Add("GroupId", CurrentUser.TenantId);
                var url = App.Configuration["GroupMealBaseUrl"] + "api/goods/GetGoodsListByIds";
                var inputData = JsonConvert.SerializeObject(ids);
                var jsonData = HttpHelper.PostData(url, inputData, Encoding.UTF8, "application/json", dic);
                var data = JsonConvert.DeserializeObject<ResultSAASManageDto<List<GoodsInfoBaseView>>>(jsonData);

                if (data.statusCode != 200)
                {
                    throw Oops.Oh(data.errors);
                }

                return data.data;
            }
            catch (Exception e)
            {
                throw Oops.Oh("请求错误");
            }

            return res;
        }

        private async Task<DiningPlateInfoDto> GetDiningPlateInfoByQRCode(string qrCode)
        {
          
            try
            {
                Dictionary<string, string> dic = new Dictionary<string, string>();
                dic.Add("GroupId", CurrentUser.TenantId);
                var url = App.Configuration["GroupMealUrl"] + "api/DiningPlate/GetDiningPlateInfoByQRCode?qrCode="+ qrCode;
                var jsonData = HttpHelper.PostData(url, "",Encoding.UTF8,"application/json", dic);
                var data = JsonConvert.DeserializeObject<ResultSAASManageDto<DiningPlateInfoDto>>(jsonData);

                if (data.statusCode != 200)
                {
                    throw Oops.Oh(data.errors);
                }
                return data.data;
            }
            catch (Exception e)
            {
                throw Oops.Oh("请求错误");
            }

        }
    }
}
